@@ -23,7 +23,7 @@ TODOs:
 """
 
 __author__ = "Andy Buckley <andy.buckley@cern.ch"
-__version__ = "1.0.7"
+__version__ = "1.0.8"
 
 
 def _autotype(var):
@@ -252,6 +252,7 @@ def readISAWIGFile(isafilename, **kwargs):
     return rtn
 
 
+
 def readISAWIG(isastr, ignorenobr=False):
     """
     Read a spectrum definition from a string in the ISAWIG format, returning
@@ -266,10 +267,31 @@ def readISAWIG(isastr, ignorenobr=False):
     branching ratio of zero.
     """
 
-    ## PDG MC ID codes mapped to HERWIG SUSY ID codes, based on
+    ## PDG MC ID codes mapped to HERWIG IDHW codes, based on
     ## http://www.hep.phy.cam.ac.uk/~richardn/HERWIG/ISAWIG/susycodes.html
+    ## + the IDPDG array and section 4.13 of the HERWIG manual.
     HERWIGID2PDGID = {}
-    HERWIGID2PDGID[203] =  25 ## HIGGSL0
+    HERWIGID2PDGID[7]   = -1
+    HERWIGID2PDGID[8]   = -2
+    HERWIGID2PDGID[9]   = -3
+    HERWIGID2PDGID[10]  = -4
+    HERWIGID2PDGID[11]  = -5
+    HERWIGID2PDGID[12]  = -6
+    HERWIGID2PDGID[13]  =  21
+    HERWIGID2PDGID[59]  =  22
+    HERWIGID2PDGID[121] =  11
+    HERWIGID2PDGID[122] =  12
+    HERWIGID2PDGID[123] =  13
+    HERWIGID2PDGID[124] =  14
+    HERWIGID2PDGID[125] =  15
+    HERWIGID2PDGID[126] =  16
+    HERWIGID2PDGID[127] = -11
+    HERWIGID2PDGID[128] = -12
+    HERWIGID2PDGID[129] = -13
+    HERWIGID2PDGID[130] = -14
+    HERWIGID2PDGID[131] = -15
+    HERWIGID2PDGID[132] = -16
+    HERWIGID2PDGID[203] =  25 ## HIGGSL0 (== PDG standard in this direction)
     HERWIGID2PDGID[204] =  35 ## HIGGSH0
     HERWIGID2PDGID[205] =  36 ## HIGGSA0
     HERWIGID2PDGID[206] =  37 ## HIGGS+
@@ -517,10 +539,31 @@ def writeISAWIG(blocks, decays, ignorenobr=False):
     If the ignorenobr parameter is True, do not write decay entries with a
     branching ratio of zero.
     """
-    ## PDG MC ID codes mapped to HERWIG SUSY ID codes, based on
+    ## PDG MC ID codes mapped to HERWIG IDHW codes, based on
     ## http://www.hep.phy.cam.ac.uk/~richardn/HERWIG/ISAWIG/susycodes.html
+    ## + the IDPDG array and section 4.13 of the HERWIG manual.
     PDGID2HERWIGID = {}
-    PDGID2HERWIGID[      25] = 203 ## HIGGSL0 (ADDED)
+    PDGID2HERWIGID[      -1] = 7
+    PDGID2HERWIGID[      -2] = 8
+    PDGID2HERWIGID[      -3] = 9
+    PDGID2HERWIGID[      -4] = 10
+    PDGID2HERWIGID[      -5] = 11
+    PDGID2HERWIGID[      -6] = 12
+    PDGID2HERWIGID[      21] = 13
+    PDGID2HERWIGID[      22] = 59
+    PDGID2HERWIGID[      11] = 121
+    PDGID2HERWIGID[      12] = 122
+    PDGID2HERWIGID[      13] = 123
+    PDGID2HERWIGID[      14] = 124
+    PDGID2HERWIGID[      15] = 125
+    PDGID2HERWIGID[      16] = 126
+    PDGID2HERWIGID[     -11] = 127
+    PDGID2HERWIGID[     -12] = 128
+    PDGID2HERWIGID[     -13] = 129
+    PDGID2HERWIGID[     -14] = 130
+    PDGID2HERWIGID[     -15] = 131
+    PDGID2HERWIGID[     -16] = 132
+    PDGID2HERWIGID[      25] = 203 ## HIGGSL0 (added for PDG standard -> HERWIG IDHW)
     PDGID2HERWIGID[      26] = 203 ## HIGGSL0
     PDGID2HERWIGID[      35] = 204 ## HIGGSH0
     PDGID2HERWIGID[      36] = 205 ## HIGGSA0
